@@ -122,10 +122,11 @@ class NNTrainer:
         eval_loaders = []
 
         for d in dataset_list:
-            eval_loaders.append(
-                self.data_handle.get_loader(handle_key=mode, dataset=d, shuffle=False,
-                                            use_padded_sampler=use_padded_sampler)
-            )
+            if d and len(d) > 0:
+                eval_loaders.append(
+                    self.data_handle.get_loader(handle_key=mode, dataset=d, shuffle=False,
+                                                use_padded_sampler=use_padded_sampler)
+                )
 
         def _update_scores(_out, _it, _avg, _metrics):
             if _out is None:
@@ -183,8 +184,6 @@ class NNTrainer:
         return it
 
     def init_training_cache(self):
-        self.set_monitor_metric()
-        self.set_log_headers()
         self.cache[Key.TRAIN_LOG] = []
         self.cache[Key.VALIDATION_LOG] = []
         self.cache['best_val_epoch'] = 0
@@ -196,7 +195,7 @@ class NNTrainer:
         if not isinstance(val_dataset, list):
             val_dataset = [val_dataset]
 
-        loader = self.data_handle.get_loader('train', dataset=train_dataset, shuffle=True)
+        loader = self.data_handle.get_loader('train', dataset=train_dataset, drop_last=True, shuffle=True)
         local_iter = self.cache.get('local_iterations', 1)
         tot_iter = len(loader) // local_iter
         for ep in range(1, self.cache['epochs'] + 1):
@@ -223,6 +222,7 @@ class NNTrainer:
                     self.on_iteration_end(i=_i, ep=ep, it=it)
 
             if val_dataset and ep % self.cache.get('validation_epochs', 1) == 0:
+                info('--- Validation ---', self.cache.get('verbose'))
                 val_averages, val_metric = self.evaluation(mode='validation', dataset_list=val_dataset,
                                                            use_padded_sampler=True)
                 self.cache[Key.VALIDATION_LOG].append([*val_averages.get(), *val_metric.get()])
@@ -305,13 +305,6 @@ class NNTrainer:
     def new_averages(self):
         return _base_metrics.COINNAverages(num_averages=1)
 
-    def set_monitor_metric(self):
-        self.cache['monitor_metric'] = 'time'
-        self.cache['metric_direction'] = 'maximize'
-
-    def set_log_headers(self):
-        self.cache['log_header'] = 'Loss'
-
     def _on_epoch_end(self, ep, **kw):
         r"""
         Any logic to run after an epoch ends.
